@@ -47,7 +47,7 @@ class Connection(object):
 
             work_progress = self._work_progress
             if work_progress:
-                past_time = time.time() - work_progress['begin_time']
+                past_time = time.perf_counter() - work_progress['begin_time']
                 if self.app.work_timeout is not None and past_time > self.app.work_timeout:
                     # 说明worker的处理时间已经太长了
                     logger.error('work timeout: %s / %s, request: %s',
@@ -154,7 +154,7 @@ class Connection(object):
 
         # 设置task开始处理的时间和信息
         self._work_progress = dict(
-            begin_time=time.time(),
+            begin_time=time.perf_counter(),
             request=request,
         )
         self._handle_request(request)
@@ -177,8 +177,8 @@ class Connection(object):
                 request.write_to_client(dict(ret=constants.RET_INVALID_CMD))
             return False
 
-        if not self.worker._got_first_request:
-            self.worker._got_first_request = True
+        if not self.worker.got_first_request:
+            self.worker.got_first_request = True
             self.app.events.before_first_request(request)
             for bp in self.app.blueprints:
                 bp.events.before_app_first_request(request)
